<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>FeatherNotes::AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="175"/>
        <source>License</source>
        <translation>Lisenssi</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::ColorLabel</name>
    <message>
        <location filename="../../colorLabel.cpp" line="31"/>
        <source>Click to change color.</source>
        <translation>Klikkaa vaihtaaksesi väriä.</translation>
    </message>
    <message>
        <location filename="../../colorLabel.cpp" line="53"/>
        <source>Select Color</source>
        <translation>Valitse väri</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::FN</name>
    <message>
        <location filename="../../fn.ui" line="14"/>
        <source>FeatherNotes</source>
        <translation>FeatherNotes</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="65"/>
        <source>Next (F3)</source>
        <translation>Seuraava (F3)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="68"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="81"/>
        <source>Previous (F4)</source>
        <translation>Edellinen (F4)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="84"/>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="100"/>
        <source>Search...</source>
        <translation>Etsittävä...</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="115"/>
        <source>Search only in names (Ctrl+Shift+F7)</source>
        <translation>Hae vain nimistä (Ctrl+Vaihto+F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="118"/>
        <source>Ctrl+Shift+F7</source>
        <translation>Ctrl+Vaihto+F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="128"/>
        <source>Search only in tags (Shift+F7)</source>
        <translation>Hae vain tageistä (Vaihto+F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="131"/>
        <source>Shift+F7</source>
        <translation>Vaihto+F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="144"/>
        <source>Search in all nodes (F7)</source>
        <translation>Hae kaikista solmuista (F7)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="147"/>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="186"/>
        <source>Whole Word (F6)</source>
        <translation>Koko sana (F6)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="189"/>
        <source>Whole Word</source>
        <translation>Koko sana</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="192"/>
        <source>F6</source>
        <translation>F6</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="167"/>
        <source>Match Case (F5)</source>
        <translation>Täsmää kirjasinkoko (F5)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="170"/>
        <source>Match Case</source>
        <translation>Täsmää kirjasinkoko</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="173"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="219"/>
        <source>&amp;File</source>
        <translation>&amp;Tiedosto</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="223"/>
        <source>Recenl&amp;y Opened</source>
        <translation>Äskettäi&amp;n avattu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="245"/>
        <source>&amp;Edit</source>
        <translation>&amp;Muokkaa</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="264"/>
        <source>For&amp;mat</source>
        <translation>M&amp;uotoilu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="296"/>
        <source>&amp;Tree</source>
        <translation>&amp;Puu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="320"/>
        <source>&amp;Options</source>
        <translation>&amp;Valinnat</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="334"/>
        <source>&amp;Search</source>
        <translation>&amp;Etsi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="341"/>
        <location filename="../../fn.ui" line="987"/>
        <source>&amp;Help</source>
        <translation>&amp;Ohje</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="436"/>
        <source>Find:</source>
        <translation>Etsi:</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="443"/>
        <source>Replace with:</source>
        <translation>Korvaa:</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="456"/>
        <source>To be replaced</source>
        <translation>Korvattava</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="469"/>
        <source>Replacing text</source>
        <translation>Korvaava teksti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="479"/>
        <source>Previous (F9)</source>
        <translation>Edellinen (F9)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="482"/>
        <source>F9</source>
        <translation>F9</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="495"/>
        <source>Next (F8)</source>
        <translation>Seuraava (F8)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="498"/>
        <source>F8</source>
        <translation>F8</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="511"/>
        <source>Replace all (F10)</source>
        <translation>Korvaa kaikki (F10)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="514"/>
        <source>F10</source>
        <translation>F10</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="531"/>
        <source>&amp;Save</source>
        <translation>&amp;Tallenna</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="534"/>
        <location filename="../../fn.cpp" line="1031"/>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="537"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="542"/>
        <location filename="../../fn.cpp" line="691"/>
        <source>&amp;Open</source>
        <translation>&amp;Avaa</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="545"/>
        <source>Open a file</source>
        <translation>Avaa tiedosto</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="548"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="556"/>
        <source>&amp;Undo</source>
        <translation>&amp;Kumoa</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="559"/>
        <source>Undo</source>
        <translation>Kumoa</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="562"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="570"/>
        <source>&amp;Redo</source>
        <translation>&amp;Tee uudelleen</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="573"/>
        <source>Redo</source>
        <translation>Tee uudelleen</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="576"/>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Vaihto+Z</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="584"/>
        <source>&amp;Find</source>
        <translation>&amp;Etsi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="587"/>
        <source>Show/hide searchbar</source>
        <translation>Näytä/piilota hakurivi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="590"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="598"/>
        <source>&amp;Clear All Formats</source>
        <translation>&amp;Poista kaikki muotoilut</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="601"/>
        <source>Clear all formats</source>
        <translation>Poista kaikki muotoilut</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="604"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="615"/>
        <source>&amp;Bold</source>
        <translation>&amp;Lihavoitu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="618"/>
        <source>Bold</source>
        <translation>Lihavoitu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="621"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="632"/>
        <source>&amp;Italic</source>
        <translation>&amp;Kursivoitu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="635"/>
        <source>Italic</source>
        <translation>Kursivoitu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="638"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="649"/>
        <source>&amp;Underline</source>
        <translation>&amp;Alleviivaus</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="652"/>
        <source>Underline</source>
        <translation>Alleviivaus</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="655"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="666"/>
        <source>&amp;Strike Through</source>
        <translation>&amp;Yliviivaus</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="669"/>
        <source>Strike through</source>
        <translation>Yliviivaus</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="672"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="680"/>
        <source>Te&amp;xt Color</source>
        <translation>Te&amp;kstin väri</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="683"/>
        <source>Text color</source>
        <translation>Tekstin väri</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="686"/>
        <source>Alt+Shift+T</source>
        <translation>Alt+Vaihto+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="694"/>
        <source>Back&amp;ground Color</source>
        <translation>Taus&amp;taväri</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="697"/>
        <source>Background color</source>
        <translation>Taustaväri</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="700"/>
        <source>Alt+Shift+B</source>
        <translation>Alt+Vaihto+B</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="705"/>
        <source>Options</source>
        <translation>Valinnat</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="710"/>
        <location filename="../../fn.cpp" line="690"/>
        <source>&amp;New Note</source>
        <translation>&amp;Uusi muistiinpano</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="713"/>
        <source>Ctrl+Alt+Shift+N</source>
        <translation>Ctrl+Alt+Vaihto+N</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="721"/>
        <source>Save &amp;As</source>
        <translation>Tallenna &amp;nimellä</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="724"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Vaihto+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="732"/>
        <source>&amp;Print</source>
        <translation>&amp;Tulosta</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="735"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="743"/>
        <source>P&amp;rint with Sub-Nodes</source>
        <translation type="unfinished">Tulosta alisolmujen kanssa</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="751"/>
        <source>Set Pass&amp;word</source>
        <translation type="unfinished">Aseta sala&amp;sana</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="756"/>
        <location filename="../../fn.cpp" line="693"/>
        <source>&amp;Quit</source>
        <translation type="unfinished">&amp;Lopeta</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="759"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="767"/>
        <source>&amp;Cut</source>
        <translation type="unfinished">&amp;Leikkaa</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="770"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="778"/>
        <source>C&amp;opy</source>
        <translation type="unfinished">&amp;Kopioi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="781"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="789"/>
        <source>&amp;Paste</source>
        <translation type="unfinished">&amp;Liitä</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="792"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="800"/>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Poista</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="808"/>
        <source>&amp;Select All</source>
        <translation type="unfinished">&amp;Valitse kaikki</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="811"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="819"/>
        <source>E&amp;mbed Image</source>
        <translation type="unfinished">L&amp;isää kuva</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="822"/>
        <location filename="../../fn.cpp" line="4378"/>
        <source>Embed Image</source>
        <translation>Lisää kuva</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="825"/>
        <source>Ctrl+Alt+Shift+I</source>
        <translation>Ctrl+Alt+Vaihto+I</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="833"/>
        <source>E&amp;xpand All</source>
        <translation type="unfinished">&amp;Laajenna kaikki</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="836"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Vaihto+Alanuoli</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="844"/>
        <source>Collap&amp;se All</source>
        <translation type="unfinished">&amp;Pienennä kaikki</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="847"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Vaihto+Ylänuoli</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="855"/>
        <source>&amp;Append Sibling</source>
        <translation type="unfinished">&amp;Lisää sisarsolmu alle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="858"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="866"/>
        <source>Append &amp;Child</source>
        <translation type="unfinished">Lisää &amp;alisolmu alle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="869"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Vaihto+N</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="877"/>
        <source>&amp;Delete Node</source>
        <translation type="unfinished">&amp;Poista solmu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="880"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="888"/>
        <source>Move &amp;Up</source>
        <translation type="unfinished">&amp;Siirrä ylös</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="891"/>
        <source>Alt+Up</source>
        <translation>Alt+Ylänuoli</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="899"/>
        <source>Move Do&amp;wn</source>
        <translation type="unfinished">&amp;Siirrä alas</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="902"/>
        <source>Alt+Down</source>
        <translation>Alt+Alanuoli</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="910"/>
        <source>Re&amp;name Node</source>
        <translation>&amp;Nimeä solmu uudelleen</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="913"/>
        <source>Ctrl+Shift+R</source>
        <translation>Ctrl+Vaihto+R</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="918"/>
        <source>Tree Pr&amp;operties</source>
        <translation type="unfinished">Puun &amp;ominaisuudet</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="921"/>
        <source>Ctrl+Shift+D</source>
        <translation>Ctrl+Vaihto+D</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="929"/>
        <source>Document &amp;Font</source>
        <translation type="unfinished">Asiakirjan &amp;fontti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="943"/>
        <source>&amp;Wrap Lines</source>
        <translation type="unfinished">&amp;Rivitä teksti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="946"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="960"/>
        <source>&amp;Auto-Indentation</source>
        <translation type="unfinished">&amp;Automaattinen sisennys</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="963"/>
        <source>Ctrl+Shift+I</source>
        <translation>Ctrl+Vaihto+I</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="968"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Asetukset</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="971"/>
        <source>Ctrl+Shift+P</source>
        <translation>Ctrl+Vaihto+P</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="979"/>
        <source>Find and &amp;Replace</source>
        <translation>Etsi ja ko&amp;rvaa</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="982"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="990"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="995"/>
        <source>&amp;About</source>
        <translation>&amp;Tietoja</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1003"/>
        <source>Pr&amp;int All Nodes</source>
        <translation>&amp;Tulosta kaikki solmut</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1014"/>
        <source>Superscrip&amp;t</source>
        <translation type="unfinished">&amp;Yläindeksi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1017"/>
        <source>Superscript</source>
        <translation>Yläindeksi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1020"/>
        <source>Alt+Shift+U</source>
        <translation>Alt+Vaihto+U</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1031"/>
        <source>Subscri&amp;pt</source>
        <translation type="unfinished">Ala&amp;indeksi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1034"/>
        <source>Subscript</source>
        <translation>Alaindeksi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1037"/>
        <source>Alt+Shift+S</source>
        <translation>Alt+Vaihto+S</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1048"/>
        <source>C&amp;enter</source>
        <translation>K&amp;eskitä</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1051"/>
        <source>Align center</source>
        <translation>Keskitä</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1054"/>
        <source>Alt+Shift+Down</source>
        <translation>Alt+Vaihto+Alanuoli</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1065"/>
        <location filename="../../fn.cpp" line="2176"/>
        <source>&amp;Right</source>
        <translation type="unfinished">&amp;Tasaus oikealle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1068"/>
        <source>Align right</source>
        <translation>Tasaus oikealle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1071"/>
        <source>Alt+Shift+Right</source>
        <translation>Alt+Vaihto+Oikea nuoli</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1082"/>
        <location filename="../../fn.cpp" line="2170"/>
        <source>&amp;Left</source>
        <translation>Tasaus &amp;vasemmalle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1085"/>
        <source>Align left</source>
        <translation>Tasaus vasemmalle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1088"/>
        <source>Alt+Shift+Left</source>
        <translation>Alt+Vaihto+Vasen nuoli</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1099"/>
        <source>&amp;Justify</source>
        <translation type="unfinished">&amp;Tasattu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1102"/>
        <source>Justify</source>
        <translation>Tasattu</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1105"/>
        <source>Alt+Shift+Up</source>
        <translation>Alt+Vaihto+Ylänuoli</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1113"/>
        <source>&amp;Prepend Sibling</source>
        <translation type="unfinished">&amp;Lisää sisarsolmu ylle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1116"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1124"/>
        <source>Move &amp;Left</source>
        <translation type="unfinished">Siirrä &amp;vasemmalle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1127"/>
        <source>Alt+Left</source>
        <translation>Alt+Vasen nuoli</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1135"/>
        <source>Move &amp;Right</source>
        <translation type="unfinished">Siirrä &amp;oikealle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1138"/>
        <source>Alt+Right</source>
        <translation>Alt+Oikea nuoli</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1146"/>
        <source>h&amp;2</source>
        <translation>h&amp;2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1149"/>
        <source>Header 2</source>
        <translation>Otsikko 2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1152"/>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1160"/>
        <source>h&amp;1</source>
        <translation>h&amp;1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1163"/>
        <source>Header 1</source>
        <translation>Otsikko 1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1166"/>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1174"/>
        <source>h&amp;3</source>
        <translation>h&amp;3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1177"/>
        <source>Header 3</source>
        <translation>Otsikko 3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1180"/>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1188"/>
        <source>&amp;Node Font</source>
        <translation>&amp;Solmun fontti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1191"/>
        <source>Node Font</source>
        <translation>Solmun fontti</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1196"/>
        <source>Scale I&amp;mage(s)</source>
        <translation type="unfinished">Muuta kuvakokoa</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1204"/>
        <source>Paste &amp;HTML</source>
        <translation type="unfinished">Liitä &amp;HTML</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1207"/>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Vaihto+V</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1215"/>
        <source>&amp;Tags</source>
        <translation>&amp;Tagit</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1218"/>
        <source>Ctrl+Shift+T</source>
        <translation>Ctrl+Vaihto+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1226"/>
        <source>Insert Lin&amp;k</source>
        <translation type="unfinished">Lisää &amp;linkki</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1229"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1234"/>
        <source>C&amp;opy Link</source>
        <translation type="unfinished">Kopioi l&amp;inkki</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1242"/>
        <source>I&amp;nsert Table</source>
        <translation type="unfinished">Lisää &amp;taulukko</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1245"/>
        <source>Ctrl+Alt+Shift+T</source>
        <translation>Ctrl+Alt+Vaihto+T</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1250"/>
        <source>Append Row</source>
        <translation>Lisää rivi alle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1255"/>
        <source>Delete Row</source>
        <translation>Poista rivi</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1260"/>
        <source>Append Column</source>
        <translation>Lisää sarake oikealle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1265"/>
        <source>Delete Column</source>
        <translation>Poista sarake</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1270"/>
        <source>Merge Cells</source>
        <translation>Yhdistä solut</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1275"/>
        <source>Prepend Row</source>
        <translation>Lisää rivi ylle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1280"/>
        <source>Prepend Column</source>
        <translation>Lisää sarake vasemmalle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1288"/>
        <source>Export &amp;HTML</source>
        <translation>Vie HTML</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1293"/>
        <source>Save Ima&amp;ge(s)</source>
        <translation type="unfinished">&amp;Tallenna kuva(t)</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1304"/>
        <source>RTL</source>
        <translation>Luku oikealta vasemmalle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1307"/>
        <source>Ctrl+Alt+Shift+Left</source>
        <translation>Ctrl+Alt+Vaihto+Vasen nuoli</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1318"/>
        <source>LTR</source>
        <translation>Luku vasemmalta oikealle</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1321"/>
        <source>Ctrl+Alt+Shift+Right</source>
        <translation>Ctrl+Alt+Vaihto+Oikea nuoli</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1326"/>
        <location filename="../../fn.ui" line="1329"/>
        <source>Menu</source>
        <translation>Valikko</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1337"/>
        <source>Node &amp;Icon</source>
        <translation type="unfinished">Solmun &amp;kuvake</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1340"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Vaihto+C</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1345"/>
        <location filename="../../fn.ui" line="1348"/>
        <source>Check Spelling</source>
        <translation>Tarkista oikeinkirjoitus</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1351"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1356"/>
        <source>Document &amp;Colors</source>
        <translation>Asiakirjan &amp;värit</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1364"/>
        <location filename="../../fn.ui" line="1367"/>
        <source>Paste Date and Time</source>
        <translation>Lisää päiväys ja aika</translation>
    </message>
    <message>
        <location filename="../../fn.ui" line="1372"/>
        <source>&amp;Clear</source>
        <translation>&amp;Tyhjennä</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2963"/>
        <source>Node Icon</source>
        <translation>Solmun kuvake</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="675"/>
        <source>&amp;Raise/Hide</source>
        <translation>&amp;Nosta/piilota</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="927"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;New note?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Uusi muistiinpano?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="928"/>
        <source>&lt;center&gt;&lt;i&gt;Do you really want to leave this document&lt;/i&gt;&lt;/center&gt;
&lt;center&gt;&lt;i&gt;and create an empty one?&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Haluatko varmasti poistua tästä asiakirjasta&lt;/i&gt;&lt;/center&gt;
&lt;center&gt;&lt;i&gt;ja luoda tyhjän?&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="931"/>
        <location filename="../../fn.cpp" line="2794"/>
        <location filename="../../fn.cpp" line="4741"/>
        <source>Yes</source>
        <translation>Kyllä</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="932"/>
        <location filename="../../fn.cpp" line="2795"/>
        <location filename="../../fn.cpp" line="4742"/>
        <source>No</source>
        <translation>Ei</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1023"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Save changes?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Tallennetaanko muutokset?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1025"/>
        <source>&lt;center&gt;&lt;i&gt;The document has been modified.&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Asiakirjaa on muokattu.&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1027"/>
        <source>&lt;center&gt;&lt;i&gt;The document has been removed.&lt;/i&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;i&gt;Asiakirja on poistettu.&lt;/i&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1032"/>
        <source>Discard changes</source>
        <translation>Hylkää muutokset</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1033"/>
        <location filename="../../fn.cpp" line="2912"/>
        <location filename="../../fn.cpp" line="3006"/>
        <location filename="../../fn.cpp" line="3279"/>
        <location filename="../../fn.cpp" line="4317"/>
        <location filename="../../fn.cpp" line="4402"/>
        <location filename="../../fn.cpp" line="4580"/>
        <location filename="../../fn.cpp" line="4843"/>
        <location filename="../../fn.cpp" line="5796"/>
        <location filename="../../fn.cpp" line="6075"/>
        <location filename="../../fn.cpp" line="6173"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1443"/>
        <source>Open file...</source>
        <translation>Avaa tiedosto…</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1620"/>
        <location filename="../../fn.cpp" line="5922"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be saved!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Tallentaminen epäonnistui!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3575"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1720"/>
        <location filename="../../fn.cpp" line="1743"/>
        <source>Save As...</source>
        <translation>Tallenna nimellä…</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1445"/>
        <location filename="../../fn.cpp" line="1722"/>
        <location filename="../../fn.cpp" line="1745"/>
        <source>FeatherNotes documents</source>
        <translation>FeatherNotes-asiakirjat</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1445"/>
        <location filename="../../fn.cpp" line="1722"/>
        <location filename="../../fn.cpp" line="1745"/>
        <location filename="../../fn.cpp" line="2995"/>
        <location filename="../../fn.cpp" line="4501"/>
        <location filename="../../fn.cpp" line="4772"/>
        <source>All Files</source>
        <translation>Kaikki tiedostot</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2791"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Delete this node?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Poistetaanko tämä solmu?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2792"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;i&gt;Warning!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
&lt;center&gt;This action cannot be undone.&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;i&gt;Varoitus!&lt;/i&gt;&lt;/b&gt;&lt;/center&gt;
&lt;center&gt;Tätä toimintaa ei voida peruuttaa.&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2898"/>
        <source>Tags</source>
        <translation>Tagit</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2913"/>
        <location filename="../../fn.cpp" line="3007"/>
        <location filename="../../fn.cpp" line="3280"/>
        <location filename="../../fn.cpp" line="4319"/>
        <location filename="../../fn.cpp" line="4403"/>
        <location filename="../../fn.cpp" line="4581"/>
        <location filename="../../fn.cpp" line="4844"/>
        <location filename="../../fn.cpp" line="5798"/>
        <location filename="../../fn.cpp" line="6076"/>
        <location filename="../../fn.cpp" line="6174"/>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2995"/>
        <location filename="../../fn.cpp" line="4501"/>
        <location filename="../../fn.cpp" line="4772"/>
        <source>Image Files</source>
        <translation>Kuvatiedostot</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3087"/>
        <location filename="../../fn.cpp" line="3120"/>
        <source>&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</source>
        <translation>&lt;b&gt;Ensisijaiset solmut:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;Kaikki solmut:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3093"/>
        <location filename="../../fn.cpp" line="3126"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;Main nodes:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;All nodes:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</source>
        <translation>&lt;b&gt;Muistiinpano:&lt;/b&gt; &lt;i&gt;%1&lt;/i&gt;&lt;br&gt;&lt;b&gt;Ensisijaiset solmut:&lt;/b&gt; &lt;i&gt;%2&lt;/i&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;Kaikki solmut:&lt;/b&gt; &lt;i&gt;%3&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3562"/>
        <source>%1 Matches</source>
        <translation>%1 osumaa</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3564"/>
        <source>One Match</source>
        <translation>Yksi osuma</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3566"/>
        <location filename="../../fn.cpp" line="3933"/>
        <source>No Match</source>
        <translation>Ei osumia</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3732"/>
        <location filename="../../fn.cpp" line="3785"/>
        <source>Replacement</source>
        <translation>Korvaus</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4040"/>
        <source>No Replacement</source>
        <translation>Ei korvattavaa</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4042"/>
        <source>One Replacement</source>
        <translation>Yksi korvattava</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4045"/>
        <source>%1 Replacements</source>
        <translation>%1 korvattavaa</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4305"/>
        <source>Insert Link</source>
        <translation>Lisää linkki</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6019"/>
        <source>HTML Files</source>
        <translation>HTML-tiedostot</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2971"/>
        <location filename="../../fn.cpp" line="4387"/>
        <source>Image path</source>
        <translation>Kuvan hakemistopolku</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2975"/>
        <location filename="../../fn.cpp" line="4391"/>
        <source>Open image</source>
        <translation>Avaa kuva</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4399"/>
        <location filename="../../fn.cpp" line="4577"/>
        <source>Scaling percentage</source>
        <translation>Skaalausprosentti</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2993"/>
        <location filename="../../fn.cpp" line="4499"/>
        <source>Open Image...</source>
        <translation>Avaa kuva...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="652"/>
        <source>System tray is not available.
Please disable tray in Preferences.</source>
        <translation>Ilmoitusalue ei ole saatavilla.
Ota pois käytöstä asetuksissa.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="978"/>
        <source>New Node</source>
        <translation>Uusi solmu</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1621"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Cannot be opened!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Avaaminen epäonnistui!&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="1702"/>
        <location filename="../../fn.cpp" line="5637"/>
        <location filename="../../fn.cpp" line="5646"/>
        <location filename="../../fn.cpp" line="5785"/>
        <location filename="../../fn.cpp" line="5976"/>
        <location filename="../../fn.cpp" line="5985"/>
        <location filename="../../fn.cpp" line="6012"/>
        <source>Untitled</source>
        <translation>Nimetön</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2169"/>
        <source>Align Table</source>
        <translation>Tasaa taulukko</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2182"/>
        <source>&amp;Center</source>
        <translation>&amp;Keskitä</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2621"/>
        <source>Select Text Color</source>
        <translation>Valitse tekstin väri</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2653"/>
        <source>Select Background Color</source>
        <translation>Valitse taustaväri</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2790"/>
        <source>Deletion</source>
        <translation>Poistaminen</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="2908"/>
        <source>Tag(s) for this node</source>
        <translation>Tagi(t) tälle solmulle</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3164"/>
        <source>Select Document Font</source>
        <translation>Valitse Asiakirjan Fontti</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3226"/>
        <source>Select Node Font</source>
        <translation>Valitse solmun fontti</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3251"/>
        <source>Set Document Colors</source>
        <translation>Valitse Asiakirjan Värit</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3261"/>
        <source>These colors will be applied to new nodes.&lt;br&gt;They may or may not affect existing nodes&lt;br&gt;but document reopening is recommended.</source>
        <translation>Nämä värit tulevat voimaan uusille solmuille.&lt;br&gt;Ne saattavat vaikuttaa olemassaoleviin solmuihin&lt;br&gt;mutta asiakirjan uudelleen avaaminen on suositeltavaa.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3264"/>
        <source>Background color:</source>
        <translation>Taustaväri:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="3270"/>
        <source>Text color:</source>
        <translation>Tekstin väri:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4050"/>
        <source>The first 1000 replacements are highlighted.</source>
        <translation>Ensimmäiset 1000 korvausta ovat korostettu.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4394"/>
        <location filename="../../fn.cpp" line="4573"/>
        <source>Scale to</source>
        <translation>Kuvan skaalaus</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4398"/>
        <location filename="../../fn.cpp" line="4576"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4567"/>
        <source>Scale Image(s)</source>
        <translation>Skaalaa kuva(t)</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4704"/>
        <source>untitled</source>
        <translation>nimetön</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4736"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4737"/>
        <source>&lt;center&gt;&lt;b&gt;&lt;big&gt;Image cannot be saved! Retry?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;b&gt;&lt;big&gt;Kuvaa ei voida tallentaa! Yritetäänkö uudelleen?&lt;/big&gt;&lt;/b&gt;&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4738"/>
        <source>&lt;center&gt;Maybe you did not choose a proper extension&lt;/center&gt;
&lt;center&gt;or do not have write permission.&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</source>
        <translation>&lt;center&gt;Tiedostopääte saattaa olla epäkelpo, tai&lt;/center&gt;
&lt;center&gt;tiedostoon ei ole kirjoitusoikeutta.&lt;/center&gt;&lt;p&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4770"/>
        <source>Save Image As...</source>
        <translation>Tallenna Kuva Nimellä...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4825"/>
        <source>Insert Table</source>
        <translation>Lisää Taulukko</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4831"/>
        <source>Rows:</source>
        <translation>Rivejä:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="4837"/>
        <source>Columns:</source>
        <translation>Sarakkeet:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5726"/>
        <source>Print Document</source>
        <translation>Tulosta asiakirja</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5732"/>
        <source>Printing completed.</source>
        <translation>Tulostus valmis.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5734"/>
        <source>Printing in progress...</source>
        <translation>Tulostaminen käynnissä...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5753"/>
        <source>Export HTML</source>
        <translation>Vie HTML</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5758"/>
        <source>Export:</source>
        <translation>Vie:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5759"/>
        <source>&amp;Current node</source>
        <translation>&amp;Valittu solmu</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5761"/>
        <source>With all &amp;sub-nodes</source>
        <translation>Kaikki &amp;alisolmut mukaan lukien</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5762"/>
        <source>&amp;All nodes</source>
        <translation>&amp;Kaikki solmut</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5774"/>
        <source>Output file:</source>
        <translation>Kohdetiedosto:</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5793"/>
        <source>Select path</source>
        <translation>Valitse hakemistopolku</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5834"/>
        <source>Question</source>
        <translation>Kysymys</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="5835"/>
        <source>The file already exists.
Do you want to replace it?
</source>
        <translation>Tiedosto on jo olemassa.
Korvataanko se?
</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6017"/>
        <source>Save HTML As...</source>
        <translation>Tallenna HTML nimellä...</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6043"/>
        <source>Set Password</source>
        <translation>Aseta salasana</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6052"/>
        <source>Type password</source>
        <translation>Syötä salasana</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6064"/>
        <source>Retype password</source>
        <translation>Toista salasana</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6136"/>
        <source>&lt;center&gt;Passwords were different. Retry!&lt;/center&gt;</source>
        <translation>&lt;center&gt;Salasanat eroavat toisistaan. Yritä uudelleen!&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6156"/>
        <location filename="../../fn.cpp" line="6164"/>
        <source>Enter Password</source>
        <translation>Syötä salasana</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6236"/>
        <source>&lt;center&gt;Wrong password. Retry!&lt;/center&gt;</source>
        <translation>&lt;center&gt;Väärä salasana. Yritä uudelleen!&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6275"/>
        <source>A lightweight notes manager</source>
        <translation>Kevyt muistiomanageri</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6276"/>
        <source>based on Qt</source>
        <translation>perustuen Qt-kirjastoon</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6277"/>
        <source>Author</source>
        <translation>Tekijä</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6279"/>
        <location filename="../../fn.cpp" line="6280"/>
        <source>About FeatherNotes</source>
        <translation>Tietoja: FeatherNotes</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6279"/>
        <source>Translators</source>
        <translation>Kääntäjät</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6463"/>
        <source>See Preferences → Text → Spell Checking!</source>
        <translation>Asetukset → Teksti → Oikeinkirjoituksen tarkistus!</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6479"/>
        <source>You need to add a Hunspell dictionary.</source>
        <translation>Hunspell-sanakirja täytyy lisätä.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6484"/>
        <source>The Hunspell dictionary does not exist.</source>
        <translation>Hunspell-sanakirjaa ei ole olemassa.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6492"/>
        <source>The Hunspell dictionary is not accompanied by an affix file.</source>
        <translation>Hunspell-sanakirjan affiksitiedosto puuttuu.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6510"/>
        <location filename="../../fn.cpp" line="6525"/>
        <location filename="../../fn.cpp" line="6537"/>
        <source>No misspelling from text cursor.</source>
        <translation>Ei kirjoitusvirheitä tekstikursorilta.</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6549"/>
        <source>Spell Checking</source>
        <translation>Oikeinkirjoituksen tarkistus</translation>
    </message>
    <message>
        <location filename="../../fn.cpp" line="6278"/>
        <source>aka.</source>
        <translation>alias</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::LineEdit</name>
    <message>
        <location filename="../../lineedit.cpp" line="35"/>
        <source>Clear text (Ctrl+K)</source>
        <translation>Tyhjennä teksti (Ctrl+K)</translation>
    </message>
    <message>
        <location filename="../../lineedit.cpp" line="81"/>
        <source>Ctrl+K</source>
        <comment>Clear text</comment>
        <translation>Ctrl+K</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::PrefDialog</name>
    <message>
        <location filename="../../prefDialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="27"/>
        <source>Window</source>
        <translation>Ikkuna</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="36"/>
        <source>Saves window size after closing
this dialog and also on exit.

Uncheck to set a fixed size!</source>
        <translation>Tallentaa ikkunan koon kun tämä
dialogi ja/tai ohjelma suljetaan.

Tyhjennä valinta pysyvän koon
asettamiseksi!</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="42"/>
        <source>Remember window &amp;size</source>
        <translation>Muista ikkunan &amp;koko</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="51"/>
        <source>Start with this size: </source>
        <translation>Aloita koolla: </translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="58"/>
        <location filename="../../prefDialog.ui" line="72"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="97"/>
        <source>Saves tree width after closing
this dialog and also on exit.

Uncheck for a width ratio of 170/530.</source>
        <translation>Tallentaa puun leveyden kun tämä
dialogi ja/tai ohjelma suljetaan.

Tyhjä valinta asettaa leveydeksi 170/530.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="103"/>
        <source>Remember &amp;tree width</source>
        <translation>Muista &amp;puun leveys</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="110"/>
        <source>Saves position after closing
this dialog and also on exit.

This may not work correctly
with some window managers.</source>
        <translation>Muistaa ikkunan sijainnin kun
tämä ikkuna ja ohjelma suljetaan.

Ei välttämättä toimi joidenkin
ikkunointiohjelmien kanssa.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="117"/>
        <source>Save &amp;position</source>
        <translation>Tallenna &amp;sijainti</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="124"/>
        <source>Decides whether a systray icon should be used.
If checked, the titlebar close button iconifies
the window to the systray instead of quitting.

Needs restarting of FeatherNotes to take effect.</source>
        <translation>Määrittelee käytetäänkö ilmoitusalueen kuvaketta.
Kun tämä on käytössä, ikkunan sulkeminen
pienentää ohjelman ilmoitusalueelle.

Vaatii FeatherNotesin uudelleenkäynnistämisen.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="131"/>
        <source>Add to s&amp;ystray</source>
        <translation>Lisää &amp;ilmoitusalueelle</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="156"/>
        <source>The command line option --tray
can be used instead of this.</source>
        <translation>Komentorivivalitsinta --tray
voidaan käyttää tämän sijasta.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="160"/>
        <source>Start i&amp;conified to tray</source>
        <translation>&amp;Aloita ilmoitusalueelle pienennettynä</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="169"/>
        <source>Merge the tree view with its surroundings?</source>
        <translation>Yhdistä puunäkymä ympäristönsä kanssa?</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="172"/>
        <source>Transparent t&amp;ree view</source>
        <translation>Läpinäkyvä p&amp;uunäkymä</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="179"/>
        <source>By default, the active widget style determines
the size of toolbar icons.</source>
        <translation>Oletuksena aktiivinen sovelmatyyli
määrittelee työkalupalkin kuvakkeiden koon.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="183"/>
        <source>Small toolbar icons</source>
        <translation>Pienet työkalupalkin kuvakkeet</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="190"/>
        <source>Do not show t&amp;oolbar</source>
        <translation>Älä näytä &amp;työkalupalkkia</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="197"/>
        <source>If the menubar is hidden,
a menu button appears on the toolbar.</source>
        <translation>Jos valikkorivi on piilotettu,
valikkonappi ilmestyy työkaluriviin.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="201"/>
        <source>Do not show &amp;menubar</source>
        <translation>Älä näytä &amp;valikkopalkkia</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="228"/>
        <source>Text</source>
        <translation>Teksti</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="237"/>
        <source>&amp;Wrap lines by default</source>
        <translation>&amp;Rivitä teksti oletuksena</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="244"/>
        <source>Auto-&amp;indent by default</source>
        <translation>&amp;Sisennä automaattisesti oletuksena</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="251"/>
        <source>This covers parentheses, braces, brackets and quotes.

Needs restarting of FeatherNotes to take effect.</source>
        <translation>Tähän sisältyy sulut, kaarisulut, hakasulut, sekä lainausmerkit.

Vaatii FeatherNotesin uudelleenkäynnistämisen.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="256"/>
        <source>Auto-&amp;bracket</source>
        <translation>Lisää hakas&amp;ulut automaattisesti</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="263"/>
        <source>A triple period is replaced with an ellipsis,
a double hyphen with a long dash, etc. while
the user is typing and under proper circumstances.</source>
        <translation>Kolmen pisteen jono korvataan ellipsillä,
kaksi väliviivaa korvataan yhdellä pitkällä viivalla, jne.
tietyissä tilanteissa kun tekstiä kirjoitetaan.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="268"/>
        <source>&amp;Replace some characters while typing</source>
        <translation>K&amp;orvaa joitakin merkkejä kun kirjoitetaan</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="277"/>
        <location filename="../../prefDialog.ui" line="290"/>
        <source>Used for pasting the date and time.
Leave empty for the system default.

Takes effect after closing this dialog.</source>
        <translation>Käytetään päiväyksen ja ajan liittämisessä.
Tyhjäksi jätettynä käytetään järjestelmän oletusta.

Otetaan käyttöön kun tämä dialogi suljetaan.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="283"/>
        <source>Date and time format:</source>
        <translation>Päivämäärän ja ajan muoto:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="307"/>
        <source>&amp;Auto-save every</source>
        <translation>&amp;Tallenna automaattisesti joka</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="314"/>
        <source> minute(s)</source>
        <translation> minuutti(a)</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="348"/>
        <source>If this option is checked, the opened document will
be saved on exiting without prompt and without
showing a warning if saving is not possible.</source>
        <translation>Avattu tiedosto tallennetaan kysymättä
ohjelmaa suljettaessa ja epäonnistuneesta
tallennuksesta ei varoiteta.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="353"/>
        <source>Save opened document on exiting</source>
        <translation>Tallenna avattu asiakirja poistuessasi</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="376"/>
        <source>Spell Checking</source>
        <translation>Oikeinkirjoituksen tarkistus</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="384"/>
        <location filename="../../prefDialog.ui" line="396"/>
        <source>A Hunspell dictionary has a name that ends with &quot;.dic&quot;
and should be alongside an affix file with the same
name but ending with &quot;.aff&quot;.</source>
        <translation>Hunspell sanakirjalla on tiedostopäätteenä &quot;.dic&quot;,
ja sen mukaan kuuluu samanniminen affiksitiedosto
jonka pääte on &quot;.aff&quot;.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="389"/>
        <source>Hunspell dictionary path:</source>
        <translation>Hunspell-sanakirjan hakemistopolku:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="408"/>
        <location filename="../../pref.cpp" line="653"/>
        <source>Add dictionary...</source>
        <translation>Lisää sanakirja...</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="443"/>
        <source>Files</source>
        <translation>Tiedostot</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="452"/>
        <source>Start with the last opened file</source>
        <translation>Aloita viimeksi avatulla tiedostolla</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="464"/>
        <source>Number of recent files:</source>
        <translation>Viimeaikaisten tiedostojen määrä:</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="496"/>
        <source>Open recent files separately</source>
        <translation>Avaa viimeaikaiset tiedostot erikseen</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="503"/>
        <source>By default, all nodes are expanded on opening a document.</source>
        <translation>Oletuksena kaikki solmut laajennetaan avattaessa dokumenttia.</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="506"/>
        <source>Remember expanded states of nodes</source>
        <translation>Muista laajennetut solmut</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="530"/>
        <source>Shortcuts</source>
        <translation>Pikänäppäimet</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="549"/>
        <source>Action</source>
        <translation>Toiminto</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="554"/>
        <source>Shortcut</source>
        <translation>Pikanäppäin</translation>
    </message>
    <message>
        <location filename="../../prefDialog.ui" line="562"/>
        <source>Default</source>
        <translation>Oletus</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="346"/>
        <location filename="../../pref.cpp" line="526"/>
        <source>Warning: Ambiguous shortcut detected!</source>
        <translation>Varoitus: Samaa yhdistelmää käytetty useammin kuin kerran!</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="509"/>
        <source>The typed shortcut was reserved.</source>
        <translation>Syötetty pikanäppäin on varattu.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="624"/>
        <source>Application restart is needed for changes to take effect.</source>
        <translation>Vaaditaan ohjelman uudelleenkäynnistys muutosten toimeen tulemiseksi.</translation>
    </message>
    <message>
        <location filename="../../pref.cpp" line="655"/>
        <source>Hunspell Dictionary Files</source>
        <translation>Hunspell-sanakirjatiedostot</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::SpellDialog</name>
    <message>
        <location filename="../../spellDialog.ui" line="25"/>
        <source>Unknown word:</source>
        <translation>Tuntematon sana:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="51"/>
        <source>Add To Dictionary</source>
        <translation>Lisää sanakirjaan</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="62"/>
        <source>Replace with:</source>
        <translation>Korvaa:</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="87"/>
        <source>Ignore Once</source>
        <translation>Ohita kerran</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="100"/>
        <source>Ignore All</source>
        <translation>Ohita kaikki</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="129"/>
        <source>Correct Once</source>
        <translation>Korjaa kerran</translation>
    </message>
    <message>
        <location filename="../../spellDialog.ui" line="142"/>
        <source>Correct All</source>
        <translation>Korjaa Kaikki</translation>
    </message>
</context>
<context>
    <name>FeatherNotes::helpDialog</name>
    <message>
        <location filename="../../helpDialog.ui" line="14"/>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../domitem.cpp" line="101"/>
        <location filename="../../domitem.cpp" line="103"/>
        <location filename="../../domitem.cpp" line="142"/>
        <location filename="../../domitem.cpp" line="144"/>
        <source>New Node</source>
        <translation>Uusi solmu</translation>
    </message>
</context>
</TS>
